/// <reference types="react" />
import * as React from 'react';
import { DateOfMonth } from './utils';
/**
 * CalendarMonth `render` prop is called with this object
 */
export interface CalendarMonthRenderProps {
    /**
     * Days of current month.
     *
     * @see Day
     * @nullable
     */
    days: Day[][];
    /**
     * Current month.
     */
    month: Date;
    /**
     * Values for creating month dropdown.
     * Months start from `0`, similar to [`Date.proptotype.getMonth()`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/getMonth).
     * By default, this value is `undefined`. To populate it, set `showDropdowns` prop as `true`.
     *
     * @default undefined
     * @see CalendarDropdownProps
     */
    monthsDropdown?: CalendarDropdownProps[];
    /**
     * Values for creating year dropdown
     * By default, this value is `undefined`. To populate it, set `showDropdowns` prop as `true`.
     *
     * @default undefined
     * @see CalendarDropdownProps
     */
    yearsDropdown?: CalendarDropdownProps[];
}
/**
 * Dropdown Value
 */
export interface CalendarDropdownProps {
    /**
     * Value of the dropdown
     */
    value: number;
    /**
     * Is the value selected?
     */
    selected: boolean;
    /**
     * Is the value disabled?
     */
    disabled: boolean;
}
/**
 * A Day of the month
 *
 * @borrows DateOfMonth
 */
export interface Day extends DateOfMonth {
    /**
     * Is the date between `startDate` and `endDate`?
     */
    inRange: boolean;
    /**
     * Is the date selected?
     */
    selected: boolean;
    /**
     * Is the date disabled?
     */
    disabled: boolean;
}
export interface CalendarMonthProps {
    /**
     * Current Month
     */
    month: Date;
    /**
     * The start of the initially selected date range
     */
    startDate?: Date;
    /**
     * The end of the initially selected date range
     */
    endDate?: Date;
    /**
     * The earliest date a user may select
     */
    minDate?: Date;
    /**
     * The latest date a user may select
     */
    maxDate?: Date;
    /**
     * If set as `true`, shows `monthsDropdown` and `yearsDropdown` are populated in `render` props.
     */
    showDropdowns?: boolean;
    /**
     * The main function, which be used for rendering.
     * It is called with an object.
     *
     * @see CalendarMonthRenderProps
     */
    render(props: CalendarMonthRenderProps): React.ReactNode;
}
/**
 * Primitive react component that can be used show a month of make a datepicker.
 *
 * @example docs/examples/SimpleDatePicker.js
 */
export declare class CalendarMonth extends React.Component<CalendarMonthProps> {
    private monthsDropdown?;
    private yearsDropdown?;
    constructor(props: CalendarMonthProps);
    componentWillReceiveProps(nextProps: CalendarMonthProps): void;
    private getDaysofMonth(props);
    getDropDowns: (props: CalendarMonthProps) => [CalendarDropdownProps[], CalendarDropdownProps[]];
    render(): React.ReactNode;
}
