import * as React from 'react';
import { startOfMonth, addMonths, isDayBefore, callIfExists } from './utils';
/**
 * Primitive react component for making a date-range picker
 *
 * @borrows CalendarMonthProps
 * @example docs/examples/SimpleDateRangePicker.js
 */
export class DateRangeControl extends React.Component {
    constructor(props) {
        super(props);
        this.handleDayClick = (day) => {
            this.setState((state) => {
                const { startDate, selectionActive } = state;
                let newState;
                if (startDate && selectionActive && !isDayBefore(day, startDate)) {
                    newState = {
                        startDate,
                        endDate: day
                    };
                    callIfExists(this.props.onDatesChange, newState);
                    return Object.assign({ selectionActive: false }, newState);
                }
                newState = {
                    startDate: day,
                    endDate: undefined
                };
                callIfExists(this.props.onDatesChange, newState);
                return Object.assign({ selectionActive: true }, newState);
            });
        };
        this.handleDayHover = (day) => {
            const { selectionActive, startDate } = this.state;
            if (selectionActive && startDate && !isDayBefore(day, startDate)) {
                this.setState(() => ({
                    endDate: day
                }));
            }
        };
        this.handleNavigation = (months) => () => {
            this.setState((state) => {
                return {
                    months: state.months.map((month) => addMonths(month, months))
                };
            });
        };
        const { startDate, endDate, showThreeMonths } = props;
        this.numOfMonths = showThreeMonths ? 3 : 2;
        const thisMonth = startOfMonth(new Date());
        this.state = {
            startDate,
            endDate,
            months: Array.from({ length: this.numOfMonths }, (_, i) => addMonths(startDate || thisMonth, i)),
            selectionActive: false
        };
    }
    componentWillReceiveProps(nextProps) {
        const { startDate, endDate } = nextProps;
        this.setState((state) => {
            return Object.assign({}, state, { startDate,
                endDate, months: Array.from({ length: this.numOfMonths }, (_, i) => addMonths(startDate || state.months[0], i)) });
        });
    }
    render() {
        const { render, minDate, maxDate } = this.props;
        const { months, startDate, endDate } = this.state;
        return render({
            months,
            startDate,
            endDate,
            minDate,
            maxDate,
            onDayClick: this.handleDayClick,
            onDayHover: this.handleDayHover,
            moveForward: this.handleNavigation(1),
            moveBackward: this.handleNavigation(-1)
        });
    }
}
